# rashdf
Read data from HEC-RAS HDF files.

## Setup
Create a virtual environment in the project directory:
```
$ python -m venv venv-rashdf
```

Activate the virtual environment:
```
$ source ./venv/bin/activate
(venv-rashdf) $
```

With the virtual environment activated, run the tests:
```
(venv-rashdf) $ pytest
```


